# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.3.2] - 2026-04-03

### Added

- Add health check tools using mcp-common
- Add PyCharm MCP tools for cross-repo code analysis

### Changed

- Update core, deps

### Internal

- Add archive/backup directories to gitignore
- Update LICENSE copyright to 2026
- Update mcp-common to 0.9.5

## [0.3.1] - 2026-02-17

### Fixed

- **BREAKING:** Default AUTH_ENABLED to false and clean git cache

### Internal

- Remove remaining oneiric_cache file from git

## [0.3.0] - 2026-02-12

### Added

- Add JWT authentication to Akosha WebSocket
- Add TLS/WSS support to Akosha WebSocket server

### Changed

- Update config, core, deps, docs
